@@ -1,11 +1,13 @@
 import json
 
-from grebble_flow.protobuf.protobuf import processor_pb2_grpc
+from grebble_flow.grpc.generated.internal.v1.processor_pb2 import FlowExecuteResponse
+
+from grebble_flow.grpc.generated.internal.v1 import processor_pb2_grpc
 from grebble_flow.helpers.converter import grebble_converter
 from grebble_flow.managment.manager import FlowManager
 
 
-class ProcessorService(processor_pb2_grpc.ExternalProcessorServicer):
+class ProcessorService(processor_pb2_grpc.ProcessorServicer):
     def __init__(self, *args, **kwargs):
         self.flow_manager = FlowManager()
 
@@ -24,12 +26,12 @@ class ProcessorService(processor_pb2_grpc.ExternalProcessorServicer):
         except:
             pass
         for item in self.flow_manager.run(flow_name, content, attributes):
-            yield processor_pb2_grpc.FlowExecuteResponse(
+            yield FlowExecuteResponse(
                 attributes=json.dumps(item.attributes, default=grebble_converter),
                 content=json.dumps(item.content, default=grebble_converter),
                 streamEnd=False,
             )
 
-        yield processor_external_pb2.FlowExecuteResponse(
+        yield FlowExecuteResponse(
             data=None, attributes=None, streamEnd=True
         )
