@@ -1,4 +1,4 @@
-from dataclasses_serialization.json import JSONSerializer
+from dataclasses_json import dataclass_json
 
 from grebble_flow.managment.processor import find_all_processors
 
@@ -20,7 +20,7 @@ class FlowManager:
         flow_processor = self.find_processor_instance_by_name(flow_name)
         attributes = None
         if flow_processor.attributes:
-            attributes = JSONSerializer.deserialize(
-                flow_processor.attributes, attributes_req
+            attributes = dataclass_json(flow_processor.attributes).from_dict(
+                attributes_req
             )
         return flow_processor.execute(content=content, attributes=attributes)
